==> hamsterdb-1.0.8.tar.gz: hamsterdb-1.0.8/unittests/error.cpp <==
/**
 * Copyright (C) 2005-2008 Christoph Rupp (chris@crupp.de).
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation; either version 2 of the License, or 
 * (at your option) any later version.
 *
 * See files COPYING.* for License information.
 */

#include <stdexcept>
#include <cstring>
#include <cppunit/extensions/HelperMacros.h>
#include <ham/hamsterdb_int.h>
#include "memtracker.h"
#include "../src/error.h"

static void
my_handler(int level, const char *msg)
{
    static int i=0;
    static const char *s[]={
        "hello world",
        "ham_verify test 1",
        "(none)",
        "hello world 42",
    };
    const char *p=strstr(msg, ": ");
    if (!p)
        return;
    p+=2;
    CPPUNIT_ASSERT_EQUAL(0, ::strcmp(s[i], p));
    i++;
}

static int g_aborted=0;

static void
my_abort_handler(void)
{ 
    g_aborted=1;
}

class ErrorTest : public CppUnit::TestFixture
{
    CPPUNIT_TEST_SUITE(ErrorTest);
    CPPUNIT_TEST      (errorHandlerTest);
    CPPUNIT_TEST      (verifyTest);
    CPPUNIT_TEST_SUITE_END();

public:
    void setUp()
    { 
    }
    
    void tearDown() 
    { 
    }

    void errorHandlerTest()
    {
        ham_set_errhandler(my_handler);
        ham_trace(("hello world"));
        ham_set_errhandler(0);
        ham_log(("testing error handler - hello world\n"));
    }

    void verifyTest()
    {
        ham_test_abort=my_abort_handler;

        g_aborted=0;
        ham_verify(0, ("ham_verify test 1"));
        CPPUNIT_ASSERT_EQUAL(1, g_aborted);
        g_aborted=0;
        ham_verify(1, ("ham_verify test 2"));
        CPPUNIT_ASSERT_EQUAL(0, g_aborted);
        g_aborted=0;
        ham_verify(!"expr", (0));
        CPPUNIT_ASSERT_EQUAL(1, g_aborted);
        ham_verify(!"expr", ("hello world %d", 42));
        CPPUNIT_ASSERT_EQUAL(1, g_aborted);

        ham_test_abort=0;
    }
};

CPPUNIT_TEST_SUITE_REGISTRATION(ErrorTest);

==> hamsterdb-1.0.9.tar.gz: hamsterdb-1.0.9/unittests/error.cpp <==
/**
 * Copyright (C) 2005-2008 Christoph Rupp (chris@crupp.de).
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation; either version 2 of the License, or 
 * (at your option) any later version.
 *
 * See files COPYING.* for License information.
 */

#include <stdexcept>
#include <cstring>
#include <cassert>
#include <ham/hamsterdb_int.h>
#include "memtracker.h"
#include "../src/error.h"

#include "bfc-testsuite.hpp"

using namespace bfc;

static void
my_handler(int level, const char *msg)
{
    static int i=0;
    static const char *s[]={
        "hello world",
        "ham_verify test 1",
        "(none)",
        "hello world 42",
    };
    const char *p=strstr(msg, ": ");
    if (!p)
        return;
    p+=2;
    assert(0==::strcmp(s[i], p));
    i++;
}

static int g_aborted=0;

static void
my_abort_handler(void)
{ 
    g_aborted=1;
}

class ErrorTest : public fixture
{
public:
    ErrorTest()
        : fixture("ErrorTest")
    {
        testrunner::get_instance()->register_fixture(this);
        BFC_REGISTER_TEST(ErrorTest, errorHandlerTest);
        BFC_REGISTER_TEST(ErrorTest, verifyTest);
    }

public:
    void setup()
    { 
    }
    
    void teardown() 
    { 
    }

    void errorHandlerTest()
    {
        ham_set_errhandler(my_handler);
        ham_trace(("hello world"));
        ham_set_errhandler(0);
        ham_log(("testing error handler - hello world\n"));
    }

    void verifyTest()
    {
        ham_test_abort=my_abort_handler;

        g_aborted=0;
        ham_verify(0, ("ham_verify test 1"));
        BFC_ASSERT_EQUAL(1, g_aborted);
        g_aborted=0;
        ham_verify(1, ("ham_verify test 2"));
        BFC_ASSERT_EQUAL(0, g_aborted);
        g_aborted=0;
        ham_verify(!"expr", (0));
        BFC_ASSERT_EQUAL(1, g_aborted);
        ham_verify(!"expr", ("hello world %d", 42));
        BFC_ASSERT_EQUAL(1, g_aborted);

        ham_test_abort=0;
    }
};

BFC_REGISTER_FIXTURE(ErrorTest);
